@@ -6,21 +6,25 @@ use std::path::PathBuf;
 use once_cell::sync::Lazy;
 
 use crate::{
-    common::{self, PATCH_SECTION},
-    erc20, simple, ProjectKind, ARGS,
+    common::{self, CL_CONTRACT, CL_TYPES, PATCH_SECTION},
+    ARGS,
 };
 
-static PACKAGE_NAME: Lazy<&'static str> = Lazy::new(|| match ARGS.project_kind() {
-    ProjectKind::Simple => "contract",
-    ProjectKind::Erc20 => "erc20-token",
-});
-
+const PACKAGE_NAME: &str = "contract";
 static CONTRACT_PACKAGE_ROOT: Lazy<PathBuf> =
     Lazy::new(|| ARGS.root_path().join(PACKAGE_NAME.replace("-", "_")));
 static CARGO_TOML: Lazy<PathBuf> = Lazy::new(|| CONTRACT_PACKAGE_ROOT.join("Cargo.toml"));
 static MAIN_RS: Lazy<PathBuf> = Lazy::new(|| CONTRACT_PACKAGE_ROOT.join("src/main.rs"));
 static CONFIG_TOML: Lazy<PathBuf> = Lazy::new(|| CONTRACT_PACKAGE_ROOT.join(".cargo/config.toml"));
 
+static CONTRACT_DEPENDENCIES: Lazy<String> = Lazy::new(|| {
+    format!(
+        "{}{}",
+        CL_CONTRACT.display_with_features(true, vec![]),
+        CL_TYPES.display_with_features(true, vec![]),
+    )
+});
+
 const CONFIG_TOML_CONTENTS: &str = r#"[build]
 target = "wasm32-unknown-unknown"
 "#;
@@ -46,25 +50,21 @@ codegen-units = 1
 lto = true
 
 {}"#,
-        *PACKAGE_NAME,
-        match ARGS.project_kind() {
-            ProjectKind::Simple => &*simple::CONTRACT_DEPENDENCIES,
-            ProjectKind::Erc20 => &*erc20::CONTRACT_DEPENDENCIES,
-        },
+        PACKAGE_NAME,
+        &*CONTRACT_DEPENDENCIES,
         PACKAGE_NAME.replace("-", "_"),
         &*PATCH_SECTION
     )
 });
 
+const MAIN_RS_CONTENTS: &str = include_str!("../resources/main.rs.in");
+
 pub fn create() {
     // Create "<PACKAGE_NAME>/src" folder and write "main.rs" inside.
     let src_folder = MAIN_RS.parent().expect("should have parent");
     common::create_dir_all(src_folder);
-    let main_rs_contents = match ARGS.project_kind() {
-        ProjectKind::Simple => simple::MAIN_RS_CONTENTS,
-        ProjectKind::Erc20 => erc20::MAIN_RS_CONTENTS,
-    };
-    common::write_file(&*MAIN_RS, main_rs_contents);
+
+    common::write_file(&*MAIN_RS, MAIN_RS_CONTENTS);
 
     // Create "<PACKAGE_NAME>/.cargo" folder and write "config.toml" inside.
     let config_folder = CONFIG_TOML.parent().expect("should have parent");
