@@ -13,10 +13,8 @@ use once_cell::sync::Lazy;
 pub mod common;
 mod contract_package;
 pub mod dependency;
-mod erc20;
 mod makefile;
 mod rust_toolchain;
-mod simple;
 mod tests_package;
 mod travis_yml;
 
@@ -24,11 +22,6 @@ const USAGE: &str = r#"cargo casper [FLAGS] <path>
     cd <path>
     make prepare
     make test"#;
-const AFTER_HELP: &str = r#"NOTE:
-    If no other flag is provided, a trivial example contract and tests are created"#;
-
-const ERC20_ARG_NAME: &str = "erc20";
-const ERC20_ARG_ABOUT: &str = "Create a basic ERC-20 contract and tests";
 
 const ROOT_PATH_ARG_NAME: &str = "path";
 const ROOT_PATH_ARG_VALUE_NAME: &str = "path";
@@ -41,15 +34,8 @@ const FAILURE_EXIT_CODE: i32 = 101;
 
 static ARGS: Lazy<Args> = Lazy::new(Args::new);
 
-#[derive(Copy, Clone, PartialEq, Eq, Debug)]
-enum ProjectKind {
-    Simple,
-    Erc20,
-}
-
 #[derive(Debug)]
 struct Args {
-    project_kind: ProjectKind,
     root_path: PathBuf,
     workspace_path: Option<PathBuf>,
 }
@@ -73,11 +59,6 @@ impl Args {
             }
         });
 
-        let project_kind_arg = Arg::new(ERC20_ARG_NAME)
-            .takes_value(false)
-            .long(ERC20_ARG_NAME)
-            .about(ERC20_ARG_ABOUT);
-
         let root_path_arg = Arg::new(ROOT_PATH_ARG_NAME)
             .required(true)
             .value_name(ROOT_PATH_ARG_VALUE_NAME)
@@ -92,18 +73,10 @@ impl Args {
             .version(crate_version!())
             .about(crate_description!())
             .override_usage(USAGE)
-            .after_help(AFTER_HELP)
-            .arg(project_kind_arg)
             .arg(root_path_arg)
             .arg(workspace_path_arg)
             .get_matches_from(filtered_args_iter);
 
-        let project_kind = if arg_matches.is_present(ERC20_ARG_NAME) {
-            ProjectKind::Erc20
-        } else {
-            ProjectKind::Simple
-        };
-
         let root_path = arg_matches
             .value_of(ROOT_PATH_ARG_NAME)
             .expect("expected path")
@@ -114,16 +87,11 @@ impl Args {
             .map(PathBuf::from);
 
         Args {
-            project_kind,
             root_path,
             workspace_path,
         }
     }
 
-    pub fn project_kind(&self) -> ProjectKind {
-        self.project_kind
-    }
-
     pub fn root_path(&self) -> &Path {
         &self.root_path
     }
