@@ -25,7 +25,7 @@ mod tests {
                 toolchain_path
             )
         });
-        toolchain_path.replace_range(index.., "/rust-toolchain");
+        toolchain_path.replace_range(index.., "/smart_contracts/rust-toolchain");
 
         let toolchain_contents =
             fs::read(&toolchain_path).unwrap_or_else(|_| panic!("should read {}", toolchain_path));
